from .dockontext import Result, container_generator_from_image

__version__ = "0.1.1"

__all__ = [
    "container_generator_from_dockerfile",
    "container_generator_from_image",
    "Result",
]
